<?php

use Phinx\Migration\AbstractMigration;

class CustomForm extends AbstractMigration
{
    /**
     * Change Method.
     *
     * Write your reversible migrations using this method.
     *
     * More information on writing migrations is available here:
     * http://docs.phinx.org/en/latest/migrations.html#the-abstractmigration-class
     *
     * The following commands can be used in this method and Phinx will
     * automatically reverse them when rolling back:
     *
     *    createTable
     *    renameTable
     *    addColumn
     *    renameColumn
     *    addIndex
     *    addForeignKey
     *
     * Remember to call "create()" or "update()" and NOT "save()" when working
     * with the Table class.
     */
    public function change()
    {
        $this->table('form', ['id' => 'form_id'])
            ->addColumn('form_statut_id', 'integer', ['default' => 1])
            ->create()
        ;

        $this->table('form_nom', ['id' => 'form_nom_id'])
            ->addColumn('form_nom_nom', 'string')
            ->addColumn('form_nom_intro_text', 'text')
            ->addColumn('form_nom_footer_text', 'text')
            ->addColumn('form_nom_footer_link', 'string')
            ->addColumn('form_nom_success', 'text')
            ->addColumn('form_nom_url', 'string')
            ->addColumn('form_id', 'integer')
            ->addColumn('langue_id', 'integer')
            ->addForeignKey(
                'form_id',
                'form',
                'form_id',
                ['delete' => 'CASCADE', 'update' => 'CASCADE']
            )
            ->addForeignKey(
                'langue_id',
                'langue',
                'langue_id',
                ['delete' => 'CASCADE', 'update' => 'CASCADE']
            )
            ->addIndex(['form_id', 'langue_id'], ['unique' => true])
            ->create()
        ;

        $this->table('form_boutique', ['id' => 'form_boutique_id'])
            ->addColumn('boutique_id', 'integer', ['null' => true])
            ->addColumn('form_id', 'integer')
            ->addForeignKey(
                'boutique_id',
                'boutique',
                'boutique_id',
                ['delete' => 'CASCADE', 'update' => 'CASCADE']
            )
            ->addForeignKey(
                'form_id',
                'form',
                'form_id',
                ['delete' => 'CASCADE', 'update' => 'CASCADE']
            )
            ->addIndex(['form_id', 'boutique_id'], ['unique' => true])
            ->create()
        ;

        $this->table('form_constraint', ['id' => 'form_constraint_id'])
            ->addColumn('form_constraint_libelle', 'string')
            ->create()
        ;

        $this->table('form_constraint')
            ->insert([
                [
                    'form_constraint_id' => 1,
                    'form_constraint_libelle' => 'Must be filled'
                ],
                [
                    'form_constraint_id' => 2,
                    'form_constraint_libelle' => 'Email'
                ],
                [
                    'form_constraint_id' =>  3,
                    'form_constraint_libelle' => 'French Phone Number'
                ],

            ])
            ->saveData()
        ;

        $this->table('form_field', ['id' => 'form_field_id'])
            ->addColumn('form_field_statut_id', 'integer', ['default' => 1])
            ->addColumn('form_id', 'integer')
            ->addForeignKey(
                'form_id',
                'form',
                'form_id',
                ['delete' => 'CASCADE', 'update' => 'CASCADE']
            )
            ->create()
        ;

        $this->table('form_field_nom', ['id' => 'form_field_nom_id'])
            ->addColumn('form_field_nom_nom', 'string')
            ->addColumn('form_field_id', 'integer')
            ->addColumn('langue_id', 'integer')
            ->addForeignKey(
                'form_field_id',
                'form_field',
                'form_field_id',
                ['delete' => 'CASCADE', 'update' => 'CASCADE']
            )
            ->addForeignKey(
                'langue_id',
                'langue',
                'langue_id',
                ['delete' => 'CASCADE', 'update' => 'CASCADE']
            )
            ->addIndex(['form_field_id', 'langue_id'], ['unique' => true])
            ->create()
        ;

        $this->table('form_field_boutique', ['id' => 'form_field_boutique_id'])
            ->addColumn('boutique_id', 'integer')
            ->addColumn('form_field_id', 'integer')
            ->addForeignKey(
                'boutique_id',
                'boutique',
                'boutique_id',
                ['delete' => 'CASCADE', 'update' => 'CASCADE']
            )
            ->addForeignKey(
                'form_field_id',
                'form_field',
                'form_field_id',
                ['delete' => 'CASCADE', 'update' => 'CASCADE']
            )
            ->addIndex(['form_field_id', 'boutique_id'], ['unique' => true])
            ->create()
        ;

        $this->table('form_field_constraint', ['id' => 'form_field_constraint_id'])
            ->addColumn('form_constraint_id', 'integer')
            ->addColumn('form_field_id', 'integer')
            ->addForeignKey(
                'form_constraint_id',
                'form_constraint',
                'form_constraint_id',
                ['delete' => 'CASCADE', 'update' => 'CASCADE']
            )
            ->addForeignKey(
                'form_field_id',
                'form_field',
                'form_field_id',
                ['delete' => 'CASCADE', 'update' => 'CASCADE']
            )
            ->addIndex(['form_field_id', 'form_constraint_id'], ['unique' => true])
            ->create()
        ;
    }
}
